# -*- coding: utf-8 -*-

"""A getter for DepMap."""

import requests

from bioversions.utils import Getter, VersionType

__all__ = [
    "DepMapGetter",
]

URL = "https://depmap.org/portal/download/api/downloads"


class DepMapGetter(Getter):
    """A getter for DepMap."""

    name = "DepMap"
    version_type = VersionType.other

    def get(self) -> str:
        """Get the latest DepMap version number."""
        res = requests.get(URL)
        latest = next(release for release in res.json()["releaseData"] if release["isLatest"])
        return latest["releaseName"][len("DepMap Public ") :]


if __name__ == "__main__":
    DepMapGetter.print()



# -*- coding: utf-8 -*-

"""Version information for bioversions."""

import os
from subprocess import CalledProcessError, check_output  # noqa: S404

__all__ = [
    "VERSION",
]

VERSION = "0.5.205"


def get_git_hash() -> str:
    """Get the bioversions git hash."""
    with open(os.devnull, "w") as devnull:
        try:
            ret = check_output(  # noqa: S603,S607
                ["git", "rev-parse", "HEAD"],
                cwd=os.path.dirname(__file__),
                stderr=devnull,
            )
        except CalledProcessError:
            return "UNHASHED"
        else:
            return ret.strip().decode("utf-8")[:8]



# -*- coding: utf-8 -*-

"""A getter for SwissLipids."""

import datetime

import requests

from bioversions.utils import Getter, VersionType

__all__ = [
    "SwissLipidGetter",
]


class SwissLipidGetter(Getter):
    """A getter for SwissLipids."""

    bioregistry_id = "slm"
    name = "SwissLipids"
    version_type = VersionType.date

    def get(self):
        """Get the latest SwissLipids version number."""
        res = requests.get("https://www.swisslipids.org/api/downloadData").json()
        record = next(record for record in res if record["file"] == "lipids.tsv")
        return datetime.datetime.strptime(record["date"], "%B %d %Y")


if __name__ == "__main__":
    SwissLipidGetter.print()
